@@ -40,7 +40,12 @@ int run_sub(config_state& rs, bool silent)
 
 	log_std(("menu: int_enable call\n"));
 
-	if (!int_enable(rs.video_font_text_x, rs.video_font_text_y, rs.video_font_text_path, rs.video_font_bar_x, rs.video_font_bar_y, rs.video_font_bar_path, rs.video_orientation_effective)) {
+	if (!int_enable(
+			rs.video_font_text_x, rs.video_font_text_y, rs.video_font_text_path,
+			rs.video_font_bar_x, rs.video_font_bar_y, rs.video_font_bar_path,
+			rs.video_font_menu_x, rs.video_font_menu_y, rs.video_font_menu_path,
+			rs.video_orientation_effective)
+	) {
 		return EVENT_ESC;
 	}
 
@@ -237,7 +242,7 @@ int run_main(config_state& rs, bool is_first, bool silent)
 
 	if (is_first) {
 		if (rs.ui_startup != "none") {
-			if (int_enable(-1, -1, "none", -1, -1, "none", rs.video_orientation_effective)) {
+			if (int_enable(-1, -1, "none", -1, -1, "none", -1, -1, "none", rs.video_orientation_effective)) {
 				int_clip(rs.ui_startup, false);
 				int_disable();
 			}
@@ -319,7 +324,7 @@ int run_main(config_state& rs, bool is_first, bool silent)
 
 	if (is_terminate) {
 		if (rs.ui_exit != "none") {
-			if (int_enable(-1, -1, "none", -1, -1, "none", rs.video_orientation_effective)) {
+			if (int_enable(-1, -1, "none", -1, -1, "none", -1, -1, "none", rs.video_orientation_effective)) {
 				wait = int_clip(rs.ui_exit, false);
 				int_disable();
 			}
