@@ -40,6 +40,10 @@
 
 #include <math.h>
 
+#ifndef __MSDOS__
+#include "dvg.h"
+#endif
+
 #if HAVE_SYS_MMAN_H
 #include <sys/mman.h> /* for mprotect */
 #endif
@@ -512,11 +516,11 @@ const mame_game* mame_game_at(unsigned i)
 /**
  * Print the information database in XML format.
  */
-void mame_print_xml(FILE* out)
+void mame_print_xml(FILE* out, int bare)
 {
 	cpuintrf_init();
 	sndintrf_init();
-	print_mame_xml(out, drivers);
+	print_mame_xml(out, bare, drivers);
 }
 
 /**
@@ -998,7 +1002,7 @@ static struct glue_keyboard_name GLUE_KEYBOARD_STD[] = {
 	KR2("period", "period", ".")
 	KR2("slash", "slash", "/")
 	KR2("colon", "colon", ":")
-	KR2("pound", "pound", "")
+	KR2("pound", "pound", "£")
 	KR2("doublequote", "doublequote", "\"")
 	KR2("diesis", "diessi", "#")
 
@@ -1074,8 +1078,8 @@ static struct mame_port GLUE_PORT_STD[] = {
 	P("doubleleft_left", "Double Left Left", JOYSTICKLEFT_LEFT)
 	P("doubleleft_right", "Double Left Right", JOYSTICKLEFT_RIGHT)
 
-	PE("paddle_left", "paddle_right", "Paddle Left", "Paddle Right", PADDLE)
-	PE("paddle_up", "paddle_down", "Paddle Up", "Paddle Down", PADDLE_V)
+	PE("paddle_right", "paddle_left", "Paddle Right", "Paddle Left", PADDLE)
+	PE("paddle_down", "paddle_up", "Paddle Down", "Paddle Up", PADDLE_V)
 
 	PE("stick_left", "stick_right", "Stick Left", "Stick Right", AD_STICK_X)
 	PE("stick_up", "stick_down", "Stick Up", "Stick Down", AD_STICK_Y)
@@ -1088,8 +1092,8 @@ static struct mame_port GLUE_PORT_STD[] = {
 	PE("pedalbrake_push", "pedalbrake_release", "Pedal Brake", "Pedal Brake Release", PEDAL2)
 	PE("pedalother_push", "pedalother_release", "Pedal Other", "Pedal Other Release", PEDAL3)
 
-	PE("dial_left", "dial_right", "Dial Left", "Dial Right", DIAL)
-	PE("dial_up", "dial_down", "Dial Up", "Dial Down", DIAL_V)
+	PE("dial_right", "dial_left", "Dial Right", "Dial Left", DIAL)
+	PE("dial_down", "dial_up", "Dial Down", "Dial Up", DIAL_V)
 
 	PE("trackball_right", "trackball_left", "Trackball Right", "Trackball Left", TRACKBALL_X)
 	PE("trackball_down", "trackball_up", "Trackball Down", "Trackball Up", TRACKBALL_Y)
@@ -1329,9 +1333,11 @@ void glue_seq_convert(unsigned* mame_seq, unsigned mame_max, unsigned* seq, unsi
 			if (c != 0) {
 				c_set = 1;
 			} else {
+				char token[128];
+				code_to_token(mame_seq[j], token);
 				c_set = 0;
 				prev_not = 0; /* remove a code specific not */
-				log_std(("WARNING:glue: unable to convert MAME code %d\n", mame_seq[j]));
+				log_std(("WARNING:glue: unable to convert MAME code %d %s\n", mame_seq[j], token));
 			}
 			break;
 		}
@@ -2127,6 +2133,9 @@ int osd_init(void)
 	add_pause_callback(osd2_video_pause);
 	add_pause_callback(osd2_sound_pause);
 	add_exit_callback(osd2_exit);
+#ifndef __MSDOS__
+	dvg_open();
+#endif
 
 	return 0;
 }
@@ -2241,6 +2250,9 @@ int osd_create_display(const osd_create_params *params, UINT32 *rgb_components)
 void osd_close_display(void)
 {
 	log_std(("osd: osd_close_display()\n"));
+#ifndef __MSDOS__
+	dvg_close();
+#endif
 
 	if (GLUE.video_flag)
 		osd2_video_done();
@@ -2624,11 +2636,11 @@ static int on_exit_menu(int selected)
 
 	if (input_ui_pressed(IPT_UI_SELECT)) {
 		switch (sel) {
-		case 0 : sel = -1; break;
-		case 1 : sel = -2; break;
-		case 2 : sel = -3; break;
-		case 3 : sel = -4; break;
-		case 4 : sel = -5; break;
+		case 0: sel = -1; break;
+		case 1: sel = -2; break;
+		case 2: sel = -3; break;
+		case 3: sel = -4; break;
+		case 4: sel = -5; break;
 		}
 	}
 
@@ -2715,15 +2727,15 @@ static int on_key_menu(int selected)
 		int key0 = 0;
 		int key1 = 0;
 		switch (sel) {
-		case 0 : key0 = KEYB_1; break;
-		case 1 : key0 = KEYB_2; break;
-		case 2 : key0 = KEYB_3; break;
-		case 3 : key0 = KEYB_4; break;
-		case 4 : key0 = KEYB_A; break;
-		case 5 : key0 = KEYB_B; break;
-		case 6 : key0 = KEYB_8; key1 = KEYB_ALT; break;
-		case 7 : key0 = KEYB_9; key1 = KEYB_ALT; break;
-		case 8 : key0 = KEYB_ENTER; break;
+		case 0: key0 = KEYB_1; break;
+		case 1: key0 = KEYB_2; break;
+		case 2: key0 = KEYB_3; break;
+		case 3: key0 = KEYB_4; break;
+		case 4: key0 = KEYB_A; break;
+		case 5: key0 = KEYB_B; break;
+		case 6: key0 = KEYB_8; key1 = KEYB_ALT; break;
+		case 7: key0 = KEYB_9; key1 = KEYB_ALT; break;
+		case 8: key0 = KEYB_ENTER; break;
 		}
 		if (key0 != 0) {
 			sel = -1;
@@ -2776,10 +2788,10 @@ int osd_handle_user_interface(mame_bitmap *bitmap, int is_menu_active)
 			mame_pause(0);
 
 			switch (res) {
-			case -2 : return 4;
-			case -3 : return 3;
-			case -4 : return 2;
-			case -5 : return 1;
+			case -2: return 4;
+			case -3: return 3;
+			case -4: return 2;
+			case -5: return 1;
 			}
 		}
 	}
